/*
 * Copyright (C) 2019 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.android.annotations.concurrency;

import java.lang.annotation.Documented;
import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

/**
 * Indicates that the target method should only be called on the UI thread. Methods running on UI
 * thread should not call {@link Slow} methods.
 *
 * <p>If the annotated element is a class, then all methods in the class should be called on the UI
 * thread.
 *
 * <p>If the annotated element is a method parameter, e.g. a {@link Runnable}, it means the callback
 * will be invoked on the UI thread.
 *
 * @see AnyThread
 */
@Documented
@Retention(RetentionPolicy.RUNTIME)
@Target({
    ElementType.METHOD,
    ElementType.CONSTRUCTOR,
    ElementType.TYPE,
    ElementType.PARAMETER,
    ElementType.TYPE_USE
})
public @interface UiThread {}
